import { PlatformPlugin, PluginType, ErrorType, HightouchError } from '@ht-sdks/events-sdk-react-native';
import { Platform } from 'react-native';
import messaging from '@react-native-firebase/messaging';
export class DeviceTokenPlugin extends PlatformPlugin {
  type = PluginType.enrichment;
  authStatus = this.checkUserPermission();
  async configure(analytics) {
    this.analytics = analytics;
    try {
      const isAuthorized = await this.authStatus;
      if (isAuthorized !== undefined && isAuthorized > 0) {
        const token = await this.getDeviceToken();
        if (token !== undefined) {
          await this.setDeviceToken(token);
        }
      } else {
        this.analytics?.logger.warn('Not authorized to retrieve device token');
      }
    } catch (error) {
      this.analytics?.reportInternalError(new HightouchError(ErrorType.PluginError, 'Unable to confirm authorization status', error));
    }
  }
  async getDeviceToken() {
    if (Platform.OS === 'ios') {
      return (await messaging().getAPNSToken()) ?? undefined;
    }
    if (Platform.OS === 'android') {
      const deviceToken = (await messaging().getToken()) ?? undefined;
      if (deviceToken !== undefined && deviceToken.length > 0) {
        return deviceToken;
      } else {
        return undefined;
      }
    }
    this.analytics?.logger.warn('Device token only available on iOS and Android platforms');
    return undefined;
  }
  async setDeviceToken(token) {
    await this.analytics?.context.set({
      device: {
        token: token
      }
    });
    await this.analytics?.track('Device Token Retrieved');
  }
  async updatePermissionStatus() {
    const isAuthorized = await this.checkUserPermission();
    if (isAuthorized !== undefined && isAuthorized > 0) {
      const token = await this.getDeviceToken();
      if (token !== undefined) {
        await this.setDeviceToken(token);
      }
    }
  }
  async checkUserPermission() {
    try {
      return await messaging().hasPermission();
    } catch (error) {
      this.analytics?.reportInternalError(new HightouchError(ErrorType.PluginError, 'Unable to confirm authorization status', error));
      return undefined;
    }
  }
}
//# sourceMappingURL=DeviceTokenPlugin.js.map